@@ -72,14 +72,14 @@ More meeting parameters.
 
 =cut
 
-=head2 create
+=head2 insert
 
-The create method is not applicable. The meeting server parameters table
+The insert method is not applicable. The meeting server parameters table
 is automatically created when you create a table.
 
 =cut
 
-sub create {shift->_not_available}
+sub insert {shift->_not_available}
 
 =head2 delete
 
